@@ -45,7 +45,7 @@ import weewx.units
 import weewx.wxformulas
 from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.10"
+VERSION = "0.11"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -164,7 +164,7 @@ class WeatherCloudThread(weewx.restx.RESTThread):
                  'humin':      ('inHumidity',   '%.0f', 1.0),  # percent
                  'uvi':        ('UV',           '%.0f', 10.0), # index * 10
                  'solarrad':   ('radiation',    '%.0f', 10.0), # W/m^2 * 10
-                 'et':         ('EV',           '%.0f', 10.0), # mm * 10
+                 'et':         ('ET',           '%.0f', 10.0), # mm * 10
                  'chill':      ('windchill',    '%.0f', 10.0), # C * 10
                  'heat':       ('heatindex',    '%.0f', 10.0), # C * 10
                  'dew':        ('dewpoint',     '%.0f', 10.0), # C * 10
